lilypondfiletools.BookpartBlock
===============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.format

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.is_formatted_when_empty

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.append

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.extend

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__contains__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__repr__

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.BookpartBlock.__str__

   .. note:: Inherited from `__builtin__.object`
